summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/pkghash.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libalpm/pkghash.h')
-rw-r--r--lib/libalpm/pkghash.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/libalpm/pkghash.h b/lib/libalpm/pkghash.h
index 617e60bd..ab8fef0c 100644
--- a/lib/libalpm/pkghash.h
+++ b/lib/libalpm/pkghash.h
@@ -27,7 +27,7 @@
/**
* @brief A hash table for holding pmpkg_t objects.
*
* A combination of a hash table and a list, allowing for fast look-up
* by package name but also iteration over the packages.
@@ -47,13 +47,13 @@ typedef struct __pmpkghash_t pmpkghash_t;
pmpkghash_t *_alpm_pkghash_create(size_t size);
-pmpkghash_t *_alpm_pkghash_add(pmpkghash_t *hash, pmpkg_t *pkg);
-pmpkghash_t *_alpm_pkghash_add_sorted(pmpkghash_t *hash, pmpkg_t *pkg);
-pmpkghash_t *_alpm_pkghash_remove(pmpkghash_t *hash, pmpkg_t *pkg, pmpkg_t **data);
+pmpkghash_t *_alpm_pkghash_add(pmpkghash_t *hash, alpm_pkg_t *pkg);
+pmpkghash_t *_alpm_pkghash_add_sorted(pmpkghash_t *hash, alpm_pkg_t *pkg);
+pmpkghash_t *_alpm_pkghash_remove(pmpkghash_t *hash, alpm_pkg_t *pkg, alpm_pkg_t **data);
void _alpm_pkghash_free(pmpkghash_t *hash);
-pmpkg_t *_alpm_pkghash_find(pmpkghash_t *hash, const char *name);
+alpm_pkg_t *_alpm_pkghash_find(pmpkghash_t *hash, const char *name);
#define MAX_HASH_LOAD 0.7
@@ -27,7 +27,7 @@
/**
- * @brief A hash table for holding pmpkg_t objects.
+ * @brief A hash table for holding alpm_pkg_t objects.
*
* A combination of a hash table and a list, allowing for fast look-up